about summary refs log tree commit diff stats
path: root/src/tools/http_upload.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/tools/http_upload.c')
-rw-r--r--src/tools/http_upload.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/tools/http_upload.c b/src/tools/http_upload.c
index 289dba15..238d71fa 100644
--- a/src/tools/http_upload.c
+++ b/src/tools/http_upload.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -45,7 +45,7 @@
 #include <pthread.h>
 #include <assert.h>
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "event/client_events.h"
 #include "tools/http_upload.h"
 #include "config/cafile.h"
@@ -245,7 +245,7 @@ http_file_put(void* userdata)
     curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, _data_callback);
     curl_easy_setopt(curl, CURLOPT_WRITEDATA, (void*)&output);
 
-    curl_easy_setopt(curl, CURLOPT_USERAGENT, "profanity");
+    curl_easy_setopt(curl, CURLOPT_USERAGENT, "profani-tty");
 
     fh = upload->filehandle;
@@ -4,20 +4,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -4,20 +4,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the